@@ -1,22 +1,6 @@
 vblpcmcovs<-function(N, model, Y, edgecovs=NULL, sendcovs=NULL, receivecovs=NULL, socialcovs=NULL)
   {
-  XX_n<-NULL
   XX_e<-matrix(rep(1,N^2),ncol=1) # all get the intercept term
-  if (model=="rreceiver")
-    {
-    # receiver random effects
-    XX_n<-cbind(XX_n,rep(1,N))
-    }
-  if (model=="rsender")
-    {
-    # sender random effects
-    XX_n<-cbind(XX_n,rep(1,N))
-    }
-  if (model=="rsocial")
-    {
-    # sender random effects
-    XX_n<-cbind(XX_n,rep(1,N),rep(1,N))
-    }
   if (!is.null(sendcovs)) # model sendcovs as edgecovs
     {
     if (!is.matrix(sendcovs))
@@ -49,7 +33,7 @@ vblpcmcovs<-function(N, model, Y, edgecovs=NULL, sendcovs=NULL, receivecovs=NULL
     }
   if (!is.null(edgecovs))
     XX_e<-cbind(XX_e,edgecovs)
-  return(list("XX_n"=XX_n,"XX_e"=XX_e))
+  return(list("XX_e"=XX_e))
   }
   
   
